<?php

namespace Bixo\Portal\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\Portal\Http\Requests\PortalRequest;
use Bixo\Portal\Interfaces\PortalRepositoryInterface;
use Bixo\Portal\Models\Portal;
use Bixo\Portal\Forms\Portal as Form;

/**
 * APIController  class for portal.
 */
class PortalAPIController extends BaseController
{

    /**
     * Initialize portal resource controller.
     *
     * @param type PortalRepositoryInterface $portal
     *
     * @return null
     */
    public function __construct(PortalRepositoryInterface $portal)
    {
        parent::__construct();
        $this->repository = $portal;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Portal\Repositories\Criteria\PortalResourceCriteria::class);
    }

    /**
     * Display a list of portal.
     *
     * @return Response
     */
    public function index(PortalRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\Portal\Repositories\Presenter\PortalPresenter::class)
            ->paginate();
    }

    /**
     * Display portal.
     *
     * @param Request $request
     * @param Model   $portal
     *
     * @return Response
     */
    public function show(PortalRequest $request, Portal $portal)
    {
        return $portal->setPresenter(\Bixo\Portal\Repositories\Presenter\PortalListPresenter::class);
        ;
    }

    /**
     * Create new portal.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PortalRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('portal::portal.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('portal/portal/' . $portal->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('portal/portal');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the portal.
     *
     * @param Request $request
     * @param Model   $portal
     *
     * @return Response
     */
    public function update(PortalRequest $request, Portal $portal)
    {
        try {
            $data = $request->all();

            $portal->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('portal::portal.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('portal/portal/' . $portal->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('portal/portal/' . $portal->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the portal.
     *
     * @param Model   $portal
     *
     * @return Response
     */
    public function destroy(PortalRequest $request, Portal $portal)
    {
        try {
            $portal->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('portal::portal.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('portal/portal/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('portal/portal/' . $portal->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
