<?php

namespace Bixo\Portal\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Portal\Models\Portal;

class PortalPolicy
{

    /**
     * Determine if the given user can view the portal.
     *
     * @param UserPolicy $user
     * @param Portal $portal
     *
     * @return bool
     */
    public function view(UserPolicy $user, Portal $portal)
    {
        if ($user->canDo('portal.portal.view') && $user->isAdmin()) {
            return true;
        }

        return $portal->user_id == user_id() && $portal->user_type == user_type();
    }

    /**
     * Determine if the given user can create a portal.
     *
     * @param UserPolicy $user
     * @param Portal $portal
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('portal.portal.create');
    }

    /**
     * Determine if the given user can update the given portal.
     *
     * @param UserPolicy $user
     * @param Portal $portal
     *
     * @return bool
     */
    public function update(UserPolicy $user, Portal $portal)
    {
        if ($user->canDo('portal.portal.edit') && $user->isAdmin()) {
            return true;
        }

        return $portal->user_id == user_id() && $portal->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given portal.
     *
     * @param UserPolicy $user
     * @param Portal $portal
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Portal $portal)
    {
        return $portal->user_id == user_id() && $portal->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given portal.
     *
     * @param UserPolicy $user
     * @param Portal $portal
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Portal $portal)
    {
        if ($user->canDo('portal.portal.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given portal.
     *
     * @param UserPolicy $user
     * @param Portal $portal
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Portal $portal)
    {
        if ($user->canDo('portal.portal.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
